@@ -1,5 +1,7 @@
 from typing import TYPE_CHECKING
 
+import httpx
+
 if TYPE_CHECKING:
     from .response import Response
     from .graphql import GraphQLResponse
@@ -9,10 +11,30 @@ class GitHubException(Exception):
     ...
 
 
+class AuthCredentialError(GitHubException):
+    """Auth Credential Error"""
+
+
+class AuthExpiredError(GitHubException):
+    """Auth Expired Error"""
+
+
+class RequestError(GitHubException):
+    """Simple API request failed with unknown error"""
+
+
+class RequestTimeout(GitHubException):
+    """Simple API request timeout"""
+
+    def __init__(self, request: httpx.Request):
+        self.request = request
+
+
 class RequestFailed(GitHubException):
     """Simple API request failed with error status code"""
 
     def __init__(self, response: "Response"):
+        self.request = response.raw_request
         self.response = response
 
     def __repr__(self) -> str:
